==> qtcreator-plugin-ubuntu_3.0.1+14.04.20140415.orig.tar.gz: qtcreator-plugin-ubuntu-3.0.1+14.04.20140415/src/ubuntu/clicktoolchain.h <==
/*
 * Copyright 2014 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 2.1.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Benjamin Zeller <benjamin.zeller@canonical.com>
 */

#ifndef UBUNTU_INTERNAL_CLICKTOOLCHAIN_H
#define UBUNTU_INTERNAL_CLICKTOOLCHAIN_H

#include <projectexplorer/gcctoolchain.h>
#include "ubuntuclicktool.h"

namespace Ubuntu {
namespace Internal {

class ClickToolChainFactory;

class ClickToolChain : public ProjectExplorer::GccToolChain
{
    friend class ClickToolChainFactory;

    // ToolChain interface
public:
    virtual QList<Utils::FileName> suggestedMkspecList() const;
    virtual Utils::FileName suggestedDebugger() const;
    virtual QString type() const;
    virtual QString typeDisplayName() const;
    virtual bool isValid() const;
    virtual void addToEnvironment(Utils::Environment &env) const;
    virtual QString makeCommand(const Utils::Environment &) const;
    virtual bool operator ==(const ProjectExplorer::ToolChain &tc) const;
    virtual ProjectExplorer::ToolChainConfigWidget *configurationWidget();
    virtual QVariantMap toMap() const;

    QString gnutriplet () const;
    const UbuntuClickTool::Target &clickTarget () const;

protected:
    virtual bool fromMap(const QVariantMap &data);

    ClickToolChain(const UbuntuClickTool::Target &target,Detection d);
    ClickToolChain(const ClickToolChain& other);
    ClickToolChain();

private:
    UbuntuClickTool::Target m_clickTarget;

    // ToolChain interface
public:
    virtual Utils::FileName compilerCommand() const;
};

class ClickToolChainFactory : public ProjectExplorer::ToolChainFactory
{
    Q_OBJECT
public:
    ClickToolChainFactory();

    // ToolChainFactory interface
public:
    virtual QList<ProjectExplorer::ToolChain *> autoDetect();
    virtual bool canRestore(const QVariantMap &data);
    virtual ProjectExplorer::ToolChain *restore(const QVariantMap &data);

    static QList<ProjectExplorer::ToolChain *> createToolChainsForClickTargets();
};

} // namespace Internal
} // namespace Ubuntu

#endif // UBUNTU_INTERNAL_CLICKTOOLCHAIN_H

==> qtcreator-plugin-ubuntu_3.1.1+15.04.20150420.1.orig.tar.gz: qtcreator-plugin-ubuntu-3.1.1+15.04.20150420.1/src/ubuntu/clicktoolchain.h <==
/*
 * Copyright 2014 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 2.1.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Benjamin Zeller <benjamin.zeller@canonical.com>
 */

#ifndef UBUNTU_INTERNAL_CLICKTOOLCHAIN_H
#define UBUNTU_INTERNAL_CLICKTOOLCHAIN_H

#include <projectexplorer/gcctoolchain.h>
#include "ubuntuclicktool.h"

namespace Ubuntu {
namespace Internal {

class ClickToolChainFactory;

class ClickToolChain : public ProjectExplorer::GccToolChain
{
    friend class ClickToolChainFactory;

    // ToolChain interface
public:
    ClickToolChain(const UbuntuClickTool::Target &target,Detection d);

    virtual QList<Utils::FileName> suggestedMkspecList() const override;
    virtual Utils::FileName suggestedDebugger() const override;
    virtual QString type() const override;
    virtual QString typeDisplayName() const override;
    virtual bool isValid() const override;
    virtual void addToEnvironment(Utils::Environment &env) const override;
    virtual QString makeCommand(const Utils::Environment &) const override;
    virtual bool operator ==(const ProjectExplorer::ToolChain &tc) const override;
    virtual ProjectExplorer::ToolChainConfigWidget *configurationWidget() override;
    virtual QVariantMap toMap() const override;

    QString gnutriplet () const;
    const UbuntuClickTool::Target &clickTarget () const;

    static ProjectExplorer::Abi architectureNameToAbi ( const QString &arch );
    static QList<QString> supportedArchitectures ();

protected:
    virtual bool fromMap(const QVariantMap &data) override;

    ClickToolChain(const ClickToolChain& other);
    ClickToolChain();

private:
    UbuntuClickTool::Target m_clickTarget;

    // ToolChain interface
public:
    virtual Utils::FileName compilerCommand() const override;
};

class ClickToolChainFactory : public ProjectExplorer::ToolChainFactory
{
    Q_OBJECT
public:
    ClickToolChainFactory();

    // ToolChainFactory interface
public:
    virtual QList<ProjectExplorer::ToolChain *> autoDetect() override;
    virtual bool canRestore(const QVariantMap &data) override;
    virtual ProjectExplorer::ToolChain *restore(const QVariantMap &data) override;

    static QList<ProjectExplorer::ToolChain *> createToolChainsForClickTargets();
};

} // namespace Internal
} // namespace Ubuntu

#endif // UBUNTU_INTERNAL_CLICKTOOLCHAIN_H
